@@ -6,8 +6,6 @@ import time
 import traceback
 from typing import Callable
 
-from dotenv import load_dotenv
-
 from .env import (
     ENGINE,
     ENGINE_EXECO,
@@ -18,9 +16,6 @@ from .env import (
 from .reporter import Reporter, Event, create_reporter
 from .types import Param
 
-# first thing first ... load dotenv file if any in the cwd
-load_dotenv(dotenv_path=Path.cwd() / ".env")
-
 LOGGER = logging.getLogger(__name__)
 
 
