@@ -1,4 +1,11 @@
 import os
+from pathlib import Path
+
+from dotenv import load_dotenv
+
+
+# first thing first ... load dotenv file if any in the cwd
+load_dotenv(dotenv_path=Path.cwd() / ".env")
 
 # engine control
 ENV_ENGINE = "MINION_ENGINE"
